@@ -8,15 +8,12 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_kms._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import cdk_iam_floyd._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-ec2-key-pair", "2.2.0", __name__[0:-6], "cdk-ec2-key-pair@2.2.0.jsii.tgz"
+    "cdk-ec2-key-pair", "3.0.0", __name__[0:-6], "cdk-ec2-key-pair@3.0.0.jsii.tgz"
 )
 
 __all__ = [
